/*------------------------------------------------------------------------------


Hello, this is the RTL version of the  main WordPress admin CSS file.
All the important stuff is in here.


TABLE OF CONTENTS:
------------------
 1.0 - Text Elements
 2.0 - Forms
 3.0 - Actions
 4.0 - Notifications
 5.0 - TinyMCE
 6.0 - Admin Header
	6.1 - Favorites Menu
	6.2 - Screen Options Tabs
 7.0 - Main Navigation
 8.0 - Layout Blocks
 9.0 - Dashboard
10.0 - List Posts
	10.1 - Inline Editing
11.0 - Write/Edit Post Screen
	11.1 - Custom Fields
	11.2 - Post Revisions
12.0 - Categories
13.0 - Tags
14.0 - Media Screen
	14.1 - Media Uploader
	14.2 - Image Editor
15.0 - Comments Screen
16.0 - Themes
	16.1 - Custom Header
	16.2 - Custom Background
	16.3 - Tabbed Admin Screen Interface
17.0 - Plugins
18.0 - Users
19.0 - Tools
20.0 - Settings
21.0 - Admin Footer
22.0 - Misc
23.0 - Dead
24.0 - TinyMCE tweaks


------------------------------------------------------------------------------*/




/*------------------------------------------------------------------------------
  1.0 - Text Styles
------------------------------------------------------------------------------*/

ol {
	margin-left: 0;
	margin-right: 2em;
}

.code, code {
	font-family: Tahoma, Arial, sans-serif;
}


.quicktags, .search {
	font: 12px Tahoma, Arial, sans-serif;
}

.icon32 {
	float: right;
	margin: 7px 0 0 8px;
}

.howto {
	font-style: normal;
	font-family: Tahoma, Arial, sans-serif;
}

p.install-help {
	font-style: normal;
}


/*------------------------------------------------------------------------------
  2.0 - Forms
------------------------------------------------------------------------------*/

#doaction,
#doaction2,
#post-query-submit {
	margin-right: 0;
	margin-left: 8px;
}

#timezone_string option {
	margin-left: 0;
	margin-right: 1em;
}

#pass-strength-result {
	float: right;
	margin: 13px 1px 5px 5px;
}

p.search-box {
	float: left;
}


/*------------------------------------------------------------------------------
  3.0 - Actions
------------------------------------------------------------------------------*/

#delete-action {
	text-align: right;
	float: right;
}

#publishing-action {
	text-align: left;
	float: left;
}

#post-body .misc-pub-section {
	border-right:0;
	border-left-width: 1px;
	border-left-style: solid;
	float: right;
}

#post-body .misc-pub-section-last {
	border-left: 0;
}

#minor-publishing-actions {
	padding: 10px 8px 2px 10px;
	text-align: left;
}

#save-post {
	float: right;
}

#minor-publishing .ajax-loading {
	padding: 3px 4px 0 0;
	float: right;
}

.preview {
	float: left;
}

#sticky-span {
	margin-left: 0;
	margin-right: 18px;
}

.side-info ul {
	padding-left: 0;
	padding-right: 18px;
}

td.action-links,
th.action-links {
	text-align: left;
}

.describe .del-link {
	padding-left: 0;
	padding-right: 5px;
}


/*------------------------------------------------------------------------------
  4.0 - Notifications
------------------------------------------------------------------------------*/

.plugin-update .update-message {
	margin: 0 31px 8px 10px;
}

form.upgrade .hint {
	font-style: normal;
}

#ajax-response.alignleft {
	margin-left: 0;
	margin-right: 2em;
}


/*------------------------------------------------------------------------------
  5.0 - TinyMCE
------------------------------------------------------------------------------*/

#quicktags {
	background-position: right top;
}

#ed_reply_toolbar input {
	margin: 1px 1px 1px 2px;
}

/* Distraction Free Writing mode
 * =Overlay Styles
-------------------------------------------------------------- */

/* No RTL for now, this space intentionally left blank */

/* =Overlay Body
-------------------------------------------------------------- */
#wp-fullscreen-body {
	right: 0;
	left:auto;
}

#wp-fullscreen-tagline {
	float: left;
}

/* =Top bar
-------------------------------------------------------------- */
#fullscreen-topbar {
	left:auto;
	right: 0;
}

#wp-fullscreen-mode-bar,
#wp-fullscreen-button-bar,
#wp-fullscreen-close,
#wp-fullscreen-count {
	float: right;
}

#wp-fullscreen-save {
	float: left;
}

#wp-fullscreen-save {
	padding: 2px 5px 0 2px;
}

#wp-fullscreen-buttons > div {
	float: right;
}

#wp-fullscreen-mode-bar {
	padding: 1px 0 0 14px;
}

#wp-fullscreen-modes a {
	float: right;
	border-width: 1px 0 1px 1px;
}

#wp-fullscreen-modes a:first-child {
	border-width: 1px;
	-moz-border-radius: 3px 3px 0 0;
	-webkit-border-top-left-radius: 0;
	-webkit-border-top-right-radius: 3px;
	-webkit-border-bottom-left-radius: 0;
	-webkit-border-bottom-right-radius: 3px;
	-khtml-border-top-left-radius: 0;
	-khtml-border-top-right-radius: 3px;
	-khtml-border-bottom-left-radius: 0;
	-khtml-border-bottom-right-radius: 3px;
	border-top-left-radius: 0;
	border-top-right-radius: 3px;
	border-bottom-right-left: 0;
	border-bottom-right-radius: 3px;
}

#wp-fullscreen-modes a:last-child {
	-moz-border-radius: 0 0 3px 3px;
	-webkit-border-top-right-radius: 0;
	-webkit-border-top-left-radius: 3px;
	-webkit-border-bottom-right-radius: 0;
	-webkit-border-bottom-left-radius: 3px;
	-khtml-border-top-right-radius: 0;
	-khtml-border-top-left-radius: 3px;
	-khtml-border-bottom-right-radius: 0;
	-khtml-border-bottom-left-radius: 3px;
	border-top-right-radius: 0;
	border-top-left-radius: 3px;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 3px;
}

#wp-fullscreen-save img,
#wp-fullscreen-save span {
	padding-right: 0;
	padding-left: 4px;
}

/* =Thickbox Adjustments
-------------------------------------------------------------- */
/* No RTL for now, this space intentionally left blank */


/* =TinyMCE Adjustments
-------------------------------------------------------------- */
/* No RTL for now, this space intentionally left blank */



/*------------------------------------------------------------------------------
  6.0 - Admin Header
------------------------------------------------------------------------------*/
#wphead {
	height: 32px;
	margin-left: 15px;
	margin-right: 2px;
}

#header-logo {
	float: right;
}

#wphead h1 {
	font: Tahoma, Arial, sans-serif;
	float: right;
}

/*------------------------------------------------------------------------------
  6.1 - Favorites Menu
------------------------------------------------------------------------------*/

#favorite-actions {
	margin: 0 15px 0 12px;
}

#favorite-first a {
	padding: 2px 12px 2px 0;
}

#favorite-inside a {
	padding: 3px 10px 3px 5px;
}

#favorite-toggle {
	right: auto;
	left: 0;
}


/*------------------------------------------------------------------------------
  6.2 - Screen Options Tabs
------------------------------------------------------------------------------*/

#screen-meta .screen-reader-text {
	visibility: hidden;
}

#contextual-help-wrap li {
	list-style-type: disc;
	margin-left: auto;
	margin-right: 18px;
}
.toggle-arrow {
	background-position: top right;
}
.toggle-arrow-active {
	background-position: bottom right;
}

#screen-options-wrap,
#contextual-help-wrap {
	margin: 0 0 0 15px;
}

.metabox-prefs label {
	padding-right: auto;
	padding-left: 15px;
}

.metabox-prefs label input {
	margin: 0 2px 0 5px;
}

/*------------------------------------------------------------------------------
  7.0 - Main Navigation (Right Menu) (RTL: Left Menu)
------------------------------------------------------------------------------*/

#adminmenushadow {
	right: auto;
	left: 0;
}

#adminmenu div.wp-menu-image {
	float: right;
}

#adminmenu .wp-submenu a {
	padding-left: 0;
	padding-right: 12px;
}

#adminmenu li.wp-has-current-submenu .wp-menu-arrow,
#adminmenu li.menu-top.current .wp-menu-arrow {
	right: auto;
	left: -9px;
}
#adminmenu .wp-menu-arrow div {
	background: url(../images/menu-arrow-frame-rtl.png) top left no-repeat;
}

#adminmenu .wp-menu-image img {
	float: right;
}

.js.folded #adminmenu .wp-submenu {
	display: block;
	left: auto;
	right: 26px;
}

.js.folded #adminmenu .wp-submenu.sub-open {
	padding: 0 0 8px 8px;
}

#adminmenu .wp-submenu .wp-submenu-head {
	padding: 6px 10px 5px 4px;
}

.js.folded #adminmenu .wp-submenu-wrap {
	-webkit-border-bottom-right-radius: 0;
	-webkit-border-bottom-left-radius: 3px;
	-webkit-border-top-right-radius: 0;
	-webkit-border-top-left-radius: 3px;
	-khtml-border-bottom-right-radius: 0;
	-khtml-border-bottom-left-radius: 3px;
	-khtml-border-top-left-radius: 0;
	-khtml-border-top-left-radius: 3px;
	-moz-border-radius-bottomright: 0;
	-moz-border-radius-bottomleft: 3px;
	-moz-border-radius-topright: 0;
	-moz-border-radius-topleft: 3px;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 3px;
	border-top-right-radius: 0;
	border-top-left-radius: 3px;
	border-width: 0 0 1px 1px;
}

.js.folded #adminmenu .wp-submenu ul {
	border-width: 0 1px 0 0;
}

.js.folded #adminmenu .wp-submenu a {
	padding-left: 0;
	padding-right: 10px;
}

.js.folded #adminmenu a.wp-has-submenu {
	margin-left: 0;
	margin-right: 40px;
}

#adminmenu .wp-menu-toggle {
	clear: left;
	float: left;
	padding: 1px 0 0 2px;
}

#adminmenu .wp-menu-image img {
	padding: 6px 1px 0 0;
}

#adminmenu .awaiting-mod,
#adminmenu span.update-plugins,
#sidemenu li a span.update-plugins {
	font-family: Tahoma, Arial, sans-serif;
	margin-left: 0;
	margin-right: 7px;
}

.post-com-count-wrapper {
	font-family: Tahoma, Arial, sans-serif;
}

.column-response .post-com-count {
	float: right;
	margin-right: 0;
	margin-left: 5px;
}

.response-links {
	float: right;
}

#collapse-button {
	float: right;
}

/*------------------------------------------------------------------------------
  8.0 - Layout Blocks
------------------------------------------------------------------------------*/

.widefat th {
	font-family: Tahoma, Arial, sans-serif;
}

.widefat td p {
	margin: 2px 0 0.8em;
}

.postbox-container {
	float: right;
	padding-right: 0;
	padding-left: 0.5%;
}

.postbox .handlediv {
	float: left;
}

/*------------------------------------------------------------------------------
  9.0 - Dashboard
------------------------------------------------------------------------------*/

#the-comment-list p.comment-author img {
	float: right;
	margin-right: 0;
	margin-left: 8px;
}

/*------------------------------------------------------------------------------
  10.0 - List Posts (/Pages/etc)
------------------------------------------------------------------------------*/

.fixed .column-comments {
	text-align: right;
}
.fixed .column-comments .vers {
	padding-left: 0;
	padding-right: 3px;
}
.fixed .column-comments a {
	float: right;
}
.sorting-indicator {
	margin-left: 0;
	margin-right: 7px;
}
th.sortable a span,
th.sorted a span {
	float: right;
}

/* Bulk Actions */

.tablenav-pages a {
	margin-right: 0;
	margin-left: 1px;
}
.tablenav-pages .next-page {
	margin-left: 0;
	margin-right: 2px;
}

.tablenav a.button-secondary {
	margin: 3px 0 0 8px;
}

.tablenav .tablenav-pages {
	float: left;
}

.tablenav .displaying-num {
	margin-right: 0;
	margin-left: 10px;
	font-family: Tahoma, Arial, sans-serif;
	font-style: bold;
}

.tablenav .actions {
	padding: 2px 0 0 8px;
}

.tablenav .delete {
	margin-right: 0;
	margin-left: 20px;
}

.view-switch {
	float: left;
}

.filter {
	float: right;
	margin: -5px 10px 0 0;
}

.filter .subsubsub {
	margin-left: 0;
	margin-right: -10px;
}

#posts-filter fieldset {
	float: right;
	margin: 0 0 1em 1.5ex;
}

#posts-filter fieldset legend {
	padding: 0 1px .2em 0;
}

/*------------------------------------------------------------------------------
  10.1 - Inline Editing
------------------------------------------------------------------------------*/

#wpbody-content .inline-edit-row fieldset {
	float: right;
}

#wpbody-content .quick-edit-row-page fieldset.inline-edit-col-right .inline-edit-col {
	border-width: 0 1px 0 0;
}

#wpbody-content .bulk-edit-row .inline-edit-col-bottom {
	float: left;
}

.inline-edit-row fieldset label span.title {
	float: right;
}

.inline-edit-row fieldset label span.input-text-wrap {
	margin-left: 0;
	margin-right: 5em;
}

.quick-edit-row-post fieldset.inline-edit-col-right label span.title {
	padding-right: 0;
	padding-left: 0.5em;
}

#wpbody-content .quick-edit-row fieldset .inline-edit-group label.alignleft:first-child {
	margin-right: 0;
	margin-left: 0.5em
}

/*	Styling */

.inline-edit-row fieldset span.title,
.inline-edit-row fieldset span.checkbox-title {
	font-family: Tahoma, Arial, sans-serif;
	font-style: normal;
}

.inline-edit-row fieldset .inline-edit-date {
	float: right;
}

.inline-edit-row fieldset ul.cat-checklist label,
.inline-edit-row .catshow,
.inline-edit-row .cathide,
.inline-edit-row #bulk-titles div {
	font-family: Tahoma, Arial, sans-serif;
}

.quick-edit-row-post fieldset label.inline-edit-status {
	float: right;
}

#bulk-titles div a {
	float: right;
	margin: 3px -2px 0 3px;
	overflow: hidden;
	text-indent: -9999px;
}


/*------------------------------------------------------------------------------
  11.0 - Write/Edit Post Screen
------------------------------------------------------------------------------*/

#titlediv #title-prompt-text,
#wp-fullscreen-title-prompt-text {
	right:0;
}

#sample-permalink {
	direction:ltr;
}

#sample-permalink #editable-post-name {
	unicode-bidi:embed;
}
#wp-fullscreen-title-prompt-text {
	left: auto;
	right: 0;
}

.postarea h3 label {
	float: right;
}

#edButtonPreview,
#edButtonHTML {
	margin: 5px 0 0 5px;
	float: left;
}

#poststuff #edButtonHTML {
	margin-right: 0;
	margin-left: 15px;
}

.submitbox .submit {
	text-align: right;
}

.inside-submitbox #post_status {
	margin: 2px -2px 2px 0;
}

.submitbox .submit input {
	margin-right: 0;
	margin-left: 4px;
}

#normal-sortables .postbox .submit {
	float: left;
}


#post-body ul.category-tabs,
#post-body ul.add-menu-item-tabs {
	float: right;
	text-align: left;
	/* Negative margin for the sake of those without JS: all tabs display */
	margin: 0 5px 0 -120px;
}


#post-body ul.category-tabs li.tabs,
#post-body ul.add-menu-item-tabs li.tabs {
	-moz-border-radius: 3px 3px 0 0;
	-webkit-border-top-left-radius: 0;
	-webkit-border-top-right-radius: 3px;
	-webkit-border-bottom-left-radius: 0;
	-webkit-border-bottom-right-radius: 3px;
	-khtml-border-top-left-radius: 0;
	-khtml-border-top-right-radius: 3px;
	-khtml-border-bottom-left-radius: 0;
	-khtml-border-bottom-right-radius: 3px;
	border-top-left-radius: 0;
	border-top-right-radius: 3px;
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 3px;
}

#post-body .categorydiv div.tabs-panel,
.taxonomy div.tabs-panel,
#post-body #linkcategorydiv div.tabs-panel {
	margin: 0 125px 0 5px;
}

#side-sortables .comments-box thead th,
#normal-sortables .comments-box thead th {
	font-style: normal;
}

#commentsdiv img.waiting {
	padding-left: 0;
	padding-right: 5px;
}

#post-body .category-tabs li.tabs,
#post-body .add-menu-item-tabs li.tabs {
	border-width: 1px 1px 1px 0;
	margin-right: 0;
	margin-left: -1px;
}

/* positioning etc. */

#posts-filter fieldset {
	float: right;
	margin: 0 0 1em 1.5ex;
}

#posts-filter fieldset legend {
	padding: 0 1px .2em 0;
}

/* Global classes */

#post-body .tagsdiv #newtag {
	margin-right: 0;
	margin-left: 5px;
}

.autosave-info {
	padding: 2px 2px 2px 15px;
	text-align: left;
}

#post-body .wp_themeSkin .mceStatusbar a.mceResize {
	background: transparent url(../images/resize-rtl.gif) no-repeat scroll left bottom;
	cursor: sw-resize;
}

.curtime #timestamp {
	background-position: right top;
	padding-left: 0;
	padding-right: 18px;
}

/*------------------------------------------------------------------------------
  11.1 - Custom Fields
------------------------------------------------------------------------------*/

#postcustomstuff table input,
#postcustomstuff table select,
#postcustomstuff table textarea {
	margin: 8px 8px 8px 0;
}

/*------------------------------------------------------------------------------
  11.2 - Post Revisions
------------------------------------------------------------------------------*/

table.diff td, table.diff th {
	font-family: Consolas, Monaco, monospace;
}

/*------------------------------------------------------------------------------
  12.0 - Categories
------------------------------------------------------------------------------*/

.category-adder {
	margin-left: 0;
	margin-right: 120px;
}


#post-body ul.category-tabs,
#post-body ul.add-menu-item-tabs {
	float: right;
	text-align: left;
	/* Negative margin for the sake of those without JS: all tabs display */
	margin: 0 5px 0 -120px;
}

#post-body ul.category-tabs li.tabs,
#post-body ul.add-menu-item-tabs li.tabs {
	-moz-border-radius: 3px 3px 0 0;
	-webkit-border-top-left-radius: 0;
	-webkit-border-top-right-radius: 3px;
	-webkit-border-bottom-left-radius: 0;
	-webkit-border-bottom-right-radius: 3px;
	-khtml-border-top-left-radius: 0;
	-khtml-border-top-right-radius: 3px;
	-khtml-border-bottom-left-radius: 0;
	-khtml-border-bottom-right-radius: 3px;
	border-top-left-radius: 0;
	border-top-right-radius: 3px;
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 3px;
}

#front-page-warning,
#front-static-pages ul,
ul.export-filters,
.inline-editor ul.cat-checklist ul,
.categorydiv ul.categorychecklist ul,
.customlinkdiv ul.categorychecklist ul,
.posttypediv ul.categorychecklist ul,
.taxonomydiv ul.categorychecklist ul,
#linkcategorydiv ul.categorychecklist ul {
	margin-left: 0;
	margin-right: 18px;
}

#post-body .category-tabs li.tabs,
#post-body .add-menu-item-tabs li.tabs {
	border-style: solid solid solid none;
	border-width: 1px 1px 1px 0;
	margin-right: 0;
	margin-left: -1px;
}

p.help,
p.description,
span.description,
.form-wrap p {
	font-style: normal;
	font-family: Tahoma, Arial, sans-serif;
}

/*------------------------------------------------------------------------------
  13.0 - Tags
------------------------------------------------------------------------------*/

.taghint {
	margin: 15px 12px -24px 0;
}

#poststuff .tagsdiv .howto {
	margin: 0 8px 6px 0;
}

.ac_results li {
	text-align: right;
}

/*------------------------------------------------------------------------------
  14.0 - Media Screen
------------------------------------------------------------------------------*/

#wpbody-content .describe th {
	text-align: right;

}

.describe .media-item-info .A1B1 {
	padding: 0 10px 0 0;
}

.media-upload-form td label {
	margin-left: 6px;
	margin-right: 2px;
}

.media-upload-form .align .field label {
	padding: 0 23px 0 0;
	margin: 0 3px 0 1em;
}

.media-upload-form tr.image-size label {
	margin: 0 5px 0 0;
}

#wpbody-content .describe p.help {
	padding: 0 5px 0 0;
}

.media-item .error-div a.dismiss,
.describe-toggle-on,
.describe-toggle-off {
	float: left;
	margin-right: 0;
	margin-left: 20px;
}

.media-item .error-div {
	padding-left: 0;
	padding-right: 10px;
}

.media-item .pinkynail {
	float: right;
}

.crunching {
	text-align: left;
	margin-right: 0;
	margin-left: 5px;
}

.bar {
	border-right-width: 0;
	border-left-width: 3px;
	border-right-style: none;
	border-left-style: solid;
}

/*------------------------------------------------------------------------------
  14.1 - Media Uploader
------------------------------------------------------------------------------*/

#find-posts-response .found-radio {
	padding: 5px 8px 0 0;
}


.find-box-search label {
	padding-right: 0;
	padding-left: 6px;
}

.find-box #resize-se {
	right: auto;
	left: 1px;
}


form.upgrade .hint {
	font-style: normal;
}


/*------------------------------------------------------------------------------
  14.2 - Image Editor
------------------------------------------------------------------------------*/

.imgedit-menu div {
	float: right;
}

.imgedit-help {
	font-style: normal;
}

.imgedit-submit-btn {
	margin-left: 0;
	margin-right: 20px;
}


/*------------------------------------------------------------------------------
  15.0 - Comments Screen
------------------------------------------------------------------------------*/

.form-table th {
	text-align: right;
}

.form-table input.tog {
	margin-right: 0;
	margin-left: 2px;
	float: right;
}

.form-table table.color-palette {
	float: right;
}

/* reply to comments */

#replysubmit img.waiting,
.inline-edit-save img.waiting {
	float: left;
}

#replysubmit .button {
	margin-right: 0;
	margin-left: 5px;
}

#edithead .inside {
	float: right;
	padding: 3px 5px 2px 0;
}

.comment-ays th {
	border-right-style: none;
	border-left-style: solid;
	border-right-width: 0;
	border-left-width: 1px;
}

.spam-undo-inside .avatar,
.trash-undo-inside .avatar {
	margin-left: 8px;
}

#comment-status-radio input {
	margin: 2px 0 5px 3px;
}



/*------------------------------------------------------------------------------
  16.0 - Themes
------------------------------------------------------------------------------*/

td.available-theme {
	text-align: right;
}

#current-theme img {
	float: right;
	margin-right: 0;
	margin-left: 1em;
}

#broken-themes {
	text-align: right;
}

/*------------------------------------------------------------------------------
  16.1 - Custom Header Screen
------------------------------------------------------------------------------*/

.appearance_page_custom-header .available-headers .default-header {
	float: right;
	margin: 0 0 20px 20px;
}

.appearance_page_custom-header .random-header {
	margin: 0 0 20px 20px;
}

.appearance_page_custom-header .available-headers label input,
.appearance_page_custom-header .random-header label input {
	margin-right: 0;
	margin-left: 10px;
}

/*------------------------------------------------------------------------------
  16.2 - Custom Background Screen
------------------------------------------------------------------------------*/

/* No RTL for now, this space intentionally left blank */


/*------------------------------------------------------------------------------
  16.3 - Tabbed Admin Screen Interface (Experimental)
------------------------------------------------------------------------------*/

.nav-tab {
	margin: 0 0 -1px 6px;
}

h2 .nav-tab {
	font-family: Tahoma, Arial, sans-serif;
}


/*------------------------------------------------------------------------------
  17.0 - Plugins
------------------------------------------------------------------------------*/

.plugins .desc ul,
.plugins .desc ol {
	margin: 0 2em 0 0;
}

#wpbody-content .plugins .plugin-title, #wpbody-content .plugins .theme-title {
	padding-right: 0;
	padding-left: 12px;
}


/*------------------------------------------------------------------------------
  18.0 - Users
------------------------------------------------------------------------------*/

#profile-page .form-table #rich_editing {
	margin-right: 0;
	margin-left: 5px
}

#your-profile legend {
	font-family: Tahoma, Arial, sans-serif;
}

/*------------------------------------------------------------------------------
  19.0 - Tools
------------------------------------------------------------------------------*/

/* Intentionally didn't RTLized the new press-this button;

/*------------------------------------------------------------------------------
  20.0 - Settings
------------------------------------------------------------------------------*/

#utc-time, #local-time {
	padding-left: 0;
	padding-right: 25px;
	font-style: normal;
	font-family: Tahoma, Arial, sans-serif;
}

/*------------------------------------------------------------------------------
  21.0 - Admin Footer
------------------------------------------------------------------------------*/

#footer {
	margin-right: 0;
	margin-left: 15px;
}

/*------------------------------------------------------------------------------
  22.0 - Misc
------------------------------------------------------------------------------*/

#template div {
	margin-right: 0;
	margin-left: 190px;
}

.column-author img, .column-username img {
	float: right;
	margin-right: 0;
	margin-left: 10px;
}

.tagchecklist {
	margin-left: 0;
	margin-right: 14px;
}

.tagchecklist strong {
	margin-left: 0;
	margin-right: -8px;
}

.tagchecklist span {
	margin-right: 0;
	margin-left: 25px;
	float: right;

}
.tagchecklist span a {
	margin: 6px -9px 0pt 0pt;
	float: right;
}

#poststuff h2 {
	clear: right;
}

#poststuff h3,
.metabox-holder h3 {
	font-family: Tahoma, Arial, sans-serif;
}

.tool-box .title {
	font-family: Tahoma, Arial, sans-serif;
}

#sidemenu {
	margin: -30px 315px 0 15px;
	float: left;
	padding-left: 0;
	padding-right: 10px;
}
#sidemenu a {
	float: right;
}

table .vers,
table .column-visible,
table .column-rating {
	text-align: right;
}


/*------------------------------------------------------------------------------
  23.0  - Dead
------------------------------------------------------------------------------*/

/* - Not used anywhere in WordPress - verify and then deprecate
------------------------------------------------------------------------------*/

/* No RTL for now, this space intentionally left blank */


/* - Only used once or twice in all of WP - deprecate for global style
------------------------------------------------------------------------------*/

* html #template div {margin-left: 0;}

.list-ajax-loading {
	float: left;
	margin-right: 0;
	margin-left: 9px;
}

/* - Used - but could/should be deprecated with a CSS reset
------------------------------------------------------------------------------*/
/* No RTL for now, this space intentionally left blank */


/*------------------------------------------------------------------------------
 24.0 - TinyMCE tweaks
		Small tweaks for until tinymce css files are proprely RTLized
------------------------------------------------------------------------------*/
#editorcontainer .wp_themeSkin .mceStatusbar {
	padding-left: 0;
	padding-right: 5px;
}
#editorcontainer .wp_themeSkin .mceStatusbar div {
	float: right;
}

#editorcontainer .wp_themeSkin .mceStatusbar a.mceResize {
	float: left;
}


/* MERGED */

/* global */

/* 2 column liquid layout */

#wpcontent {
	margin-left: 0;
	margin-right: 165px;
}

.wp-admin #footer {
	margin-left: 15px;
	margin-right: 165px;
}

.js.folded #wpcontent {
	margin-left: 0;
	margin-right: 52px;
}

.js.folded.wp-admin #footer {
	margin-left: 15px;
	margin-right: 52px;
}

#wpbody-content {
	float: right;
}

#adminmenuwrap {
	float: right;
}

#adminmenu {
	clear: right;
}

/* inner 2 column liquid layout */
.inner-sidebar {
	float: left;
	clear: left;
}

.has-right-sidebar #post-body {
	float: right;
	clear: right;
	margin-right: 0;
	margin-left: -340px;
}

.has-right-sidebar #post-body-content {
	margin-right: 0;
	margin-left: 300px;
}

/* 2 columns main area */

#col-right {
	float: left;
	clear: left;
}

/* utility classes*/
.alignleft {
	float: right;
}

.alignright {
	float: left;
}

.textleft {
	text-align: right;
}

.textright {
	text-align: left;
}

/* Hide visually but not from screen readers */
.screen-reader-text, .screen-reader-text span {
	left: auto;
	right: -1000em;
}

/* styles for use by people extending the WordPress interface */

body,
td,
textarea,
input,
select {
	font-family: Tahoma, Arial, sans-serif;
}

ul.ul-disc,
ul.ul-square,
ol.ol-decimal {
	margin-left: 0;
	margin-right: 1.8em;
}

.subsubsub {
	float: right;
}

.widefat thead th:first-of-type {
	-moz-border-radius-topleft: 0;
	-moz-border-radius-topright: 3px;
	-khtml-border-top-left-radius: 0;
	-khtml-border-top-right-radius: 3px;
	-webkit-border-top-left-radius: 0;
	-webkit-border-top-right-radius: 3px;
	border-top-left-radius: 0;
	border-top-right-radius: 3px;
}

.widefat thead th:last-of-type {
	-moz-border-radius-topright: 0;
	-moz-border-radius-topleft: 3px;
	-khtml-border-top-right-radius: 0;
	-khtml-border-top-left-radius: 3px;
	-webkit-border-top-right-radius: 0;
	-webkit-border-top-left-radius: 3px;
	border-top-right-radius: 0;
	border-top-left-radius: 3px;
}
.widefat tfoot th:first-of-type {
	-moz-border-radius-bottomleft: 0;
	-moz-border-radius-bottomright: 3px;
	-khtml-border-bottom-left-radius: 0;
	-khtml-border-bottom-right-radius: 3px;
	-webkit-border-bottom-left-radius: 0;
	-webkit-border-bottom-right-radius: 3px;
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 3px;
}
.widefat tfoot th:last-of-type {
	-moz-border-radius-bottomright: 0;
	-moz-border-radius-bottomleft: 3px;
	-khtml-border-bottom-right-radius: 0;
	-khtml-border-bottom-left-radius: 3px;
	-webkit-border-bottom-right-radius: 0;
	-webkit-border-bottom-left-radius: 3px;
	border-bottom-right-radius: 0;
	border-bottom-left-radius: 3px;
}

.widefat th {
	text-align: right;
}

.widefat th input {
	margin: 0 8px 0 0;
}

.wrap {
	margin: 0 0 0 15px;
}


.wrap h2,
.subtitle {
	font-family: Tahoma, Arial, sans-serif;
}
.wrap h2 {
	padding: 9px 0 4px 15px;
}

.subtitle {
	padding-left: 0;
	padding-right: 25px;
}

.wrap .add-new-h2 {
	font-family: Tahoma, Arial, sans-serif;
	margin-left: 0;
	margin-right: 4px;
}

.wrap h2.long-header {
	padding-left: 0;
}


/* dashboard */
#dashboard-widgets-wrap .has-sidebar {
	margin-right: 0;
	margin-left: -51%;
}
#dashboard-widgets-wrap .has-sidebar .has-sidebar-content {
	margin-right: 0;
	margin-left: 51%;
}
.view-all {
	right: auto;
	left: 0;
}
#dashboard_right_now p.sub, #dashboard-widgets h4, #dashboard_quick_press h4, a.rsswidget, #dashboard_plugins h4, #dashboard_plugins h5, #dashboard_recent_comments .comment-meta .approve {
	font-family: Tahoma, Arial;
}
#dashboard_right_now p.sub  {
	left:auto;
	right:15px;
}
#dashboard_right_now td.b {
	padding-right: 0;
	padding-left: 6px;
	text-align: left;
	font-family: Tahoma, Arial;
}
#dashboard_right_now .t {
	padding-right: 0;
	padding-left: 12px;
}
#dashboard_right_now .table_content {
	float:right;
}
#dashboard_right_now .table_discussion {
	float:left;
}
#dashboard_right_now .versions a {
	font-family: Tahoma, Arial;
}
#dashboard_right_now a.button {
	float: left;
	clear: left;
}
#dashboard_plugins .inside span {
	 padding-left: 0;
	 padding-right: 5px;
}
#dashboard-widgets h3 .postbox-title-action {
	right: auto;
	left: 30px;
}
#the-comment-list .pingback {
	padding-left: 0 !important;
	padding-right: 9px !important;
}
/* Recent Comments */
#the-comment-list .comment-item {
	padding: 1em 70px 1em 10px;
}
#the-comment-list .comment-item .avatar {
	float: right;
	margin-left: 0;
	margin-right: -60px;
}
/* Feeds */
.rss-widget cite {
	text-align: left;
}
.rss-widget span.rss-date {
	font-family: Tahoma, Arial;
	margin-left: 0;
	margin-right: 3px;
}
/* QuickPress */
#dashboard_quick_press h4 {
	float: right;
	text-align: left;
}
#dashboard_quick_press h4 label {
	margin-right: 0;
	margin-left: 10px;
}
#dashboard_quick_press .input-text-wrap, #dashboard_quick_press .textarea-wrap {
	margin: 0 5em 1em 0;
}
#dashboard_quick_press #media-buttons {
	margin: 0 5em .5em 0;
	padding: 0;
}

#dashboard-widgets #dashboard_quick_press form p.submit {
	margin-left: 0;
	margin-right: 4.6em;
}
#dashboard-widgets #dashboard_quick_press form p.submit input {
	float: right;
}
#dashboard-widgets #dashboard_quick_press form p.submit #save-post {
	margin: 0 10px 0 1em;
}
#dashboard-widgets #dashboard_quick_press form p.submit #publish {
	float: left;
}
#dashboard-widgets #dashboard_quick_press form p.submit img.waiting {
	margin: 4px 0 0 6px;
}
/* Recent Drafts */
#dashboard_recent_drafts h4 abbr {
	font-family: Tahoma, Arial;
	margin-left:0;
	margin-right: 3px;
}


/* login */
body {
	font-family: Tahoma, arial;
}
form {
	margin-right: 8px;
	margin-left: 0;
}
form .forgetmenot {
	float: right;
}
#login form .submit input {
	font-family: Tahoma, arial;
}
form .submit { float: left; }
#backtoblog a {
	padding: 8px 15px 0 0;
}
#login_error, .message {
	margin: 0 8px 16px 0;
}
#nav { margin: 0 8px 0 0; }
#user_pass, #user_login, #user_email {
	margin-left: 6px;
	margin-right: 0;
	direction:ltr;
}
h1 a {
	text-decoration: none;
}





/* nav-menu */
#nav-menus-frame {
	margin-right: 300px;
	margin-left: 0;
}

#wpbody-content #menu-settings-column {
	margin-right: -300px;
	margin-left: 0;
	float: right;
}

/* Menu Container */
#menu-management-liquid {
	float: right;
}
#menu-management {
	margin-left: 20px;
	margin-right: 0;
}


	#post-body {
		padding:0 10px 10px 0;
	}

	.post-body-plain {
		padding: 10px 0 0 10px;
	}

/* Menu Tabs */

	#menu-management .nav-tabs-arrow-left {
		right: 0;
		left:auto;
	}
	#menu-management .nav-tabs-arrow-right {
		left: 0;
		right:auto;
		text-align: left;
		font-family: Tahoma, Arial, sans-serif;
	}

#menu-management .nav-tabs {
	padding-right: 20px;
	padding-left: 10px;
}
.js #menu-management .nav-tabs {
	float: right;
	margin-right: 0px;
	margin-left: -400px;
}

#select-nav-menu-container {
	text-align: left;
}

#wpbody .open-label {
	float:right;
}

#wpbody .open-label span {
	padding-left: 10px;
	padding-right:0;
}

	.js .input-with-default-title {
		font-style: normal;
		font-weight:bold;
	}

/* Add Menu Item Boxes */
.postbox .howto input {
	float: left;
}
#nav-menu-theme-locations .button-controls {
	text-align: left;
}

/* Button Primary Actions */

.meta-sep,
.submitdelete,
.submitcancel {
	float:right;
}

#cancel-save {
	margin-left: 0;
	margin-right: 20px;
}

/* Button Secondary Actions */
.list-controls {
	 float: right;
}
.add-to-menu {
	float: left;
}

/* Custom Links */
#add-custom-link label span { float: right; padding-left: 5px; padding-right:0;}
.howto span { float: right; }

.list li .menu-item-title input { margin-left: 3px; margin-right: 0 }

/* Nav Menu */
.menu-item-handle {
	padding-right: 10px;
	padding-left: 0;
}
.menu-item-edit-active .menu-item-handle {
	-moz-border-radius: 3px 3px 0 0;
	-webkit-border-bottom-left-radius: 0;
	-webkit-border-bottom-right-radius: 0;
	-khtml-border-bottom-left-radius: 0;
	-khtml-border-bottom-right-radius: 0;
	border-bottom-left-radius: 0;
	border-bottom-right-radius: 0;
}
.menu-item-handle .item-title {
	margin-left:13em;
	margin-right:0;
}


/* WARNING: The factor of 30px is hardcoded into the nav-menus javascript. */
.menu-item-depth-0 { margin-right: 0px; margin-left:0;}
.menu-item-depth-1 { margin-right: 30px; margin-left:0;}
.menu-item-depth-2 { margin-right: 60px; margin-left:0;}
.menu-item-depth-3 { margin-right: 90px; margin-left:0;}
.menu-item-depth-4 { margin-right: 120px; margin-left:0;}
.menu-item-depth-5 { margin-right: 150px; margin-left:0;}
.menu-item-depth-6 { margin-right: 180px; margin-left:0;}
.menu-item-depth-7 { margin-right: 210px; margin-left:0;}
.menu-item-depth-8 { margin-right: 240px; margin-left:0;}
.menu-item-depth-9 { margin-right: 270px; margin-left:0;}
.menu-item-depth-10 { margin-right: 300px; margin-left:0;}
.menu-item-depth-11 { margin-right: 330px; margin-left:0;}

.menu-item-depth-0 .menu-item-transport { margin-right: 0px; margin-left:0;}
.menu-item-depth-1 .menu-item-transport { margin-right: -30px; margin-left:0;}
.menu-item-depth-2 .menu-item-transport { margin-right: -60px; margin-left:0;}
.menu-item-depth-3 .menu-item-transport { margin-right: -90px; margin-left:0;}
.menu-item-depth-4 .menu-item-transport { margin-right: -120px; margin-left:0;}
.menu-item-depth-5 .menu-item-transport { margin-right: -150px; margin-left:0;}
.menu-item-depth-6 .menu-item-transport { margin-right: -180px; margin-left:0;}
.menu-item-depth-7 .menu-item-transport { margin-right: -210px; margin-left:0;}
.menu-item-depth-8 .menu-item-transport { margin-right: -240px; margin-left:0;}
.menu-item-depth-9 .menu-item-transport { margin-right: -270px; margin-left:0;}
.menu-item-depth-10 .menu-item-transport { margin-right: -300px; margin-left:0;}
.menu-item-depth-11 .menu-item-transport { margin-right: -330px; margin-left:0;}

/* Menu item controls */
.item-type { padding-left: 10px;  padding-right:0;}
.item-controls { left: 20px; right: auto;}
.item-controls .item-order { padding-left: 10px; padding-right: 0;}

.item-edit {
	left: -20px;
	right:auto;
	-moz-border-radius-bottomright: 3px;
	-moz-border-radius-bottomleft: 0;
	-webkit-border-bottom-right-radius: 3px;
	-webkit-border-bottom-left-radius: 0;
	-khtml-border-bottom-right-radius: 3px;
	-khtml-border-bottom-left-radius: 0;
	border-bottom-right-radius: 3px;
	border-bottom-left-radius: 0;
}

/* Menu editing */
.menu-item-settings {
	padding: 10px 10px 10px 0;
	border-width: 0 1px 1px 1px;
}

.link-to-original {
	font-style: normal;
	font-weight: bold;
}
	.link-to-original a {
		padding-right: 4px;
		padding-left:0;
	}

.menu-item-settings .description-thin,
.menu-item-settings .description-wide {
	margin-left: 10px;
	margin-right:0;
	float: right;
}

/* Major/minor publishing actions (classes) */
.major-publishing-actions .publishing-action {
	text-align: left;
	float: left;
}
.major-publishing-actions .delete-action {
	text-align: right;
	float: right;
	padding-left: 15px;
	padding-right:0;
}
.menu-name-label {
	margin-left: 15px;
	margin-right:0;
}
.auto-add-pages {
	float: right;
}




/* plugin-install */
div.star {
	left: auto;
	right: 0;
	letter-spacing: 0;
}
.star img, div.star a, div.star a:hover, div.star a:visited {
	right: auto;
	left: 0;
}
#plugin-information ul#sidemenu {
	left: auto;
	right: 0;
}
#plugin-information h2 {
	margin-right: 0;
	margin-left: 200px;
}
#plugin-information .fyi {
	margin-left: 5px;
	margin-right: 20px;
}
#plugin-information .fyi h2 {
	margin-left: 0;
}
#plugin-information .fyi ul {
	padding: 10px 7px 10px 5px;
}
#plugin-information #section-screenshots li p {
	padding-left: 0;
	padding-right: 20px;
}
#plugin-information .updated,
#plugin-information pre {
	margin-right: 0;
	margin-left: 215px;
}
#plugin-information .updated, #plugin-information .error {
	clear: none;
	direction: rtl;
}
#section-description {
	direction: ltr;
}




/* press-this */
body {
	font-family: Tahoma, Arial;
}

#poststuff #edButtonPreview,
#poststuff #edButtonHTML {
	float: left;
}

#poststuff #edButtonHTML {
	margin-left: 15px;
	margin-right: 5px;
}

#header-logo,
#wphead h1 {
	float: right;
}

/* Editor/Main Column */
div#poststuff {
	padding-left: 0;
	padding-right: 10px;
}

.posting {
	margin-left: 212px;
	margin-right: 0;
	position: relative;
}

#side-info-column {
	float: left;
	right: auto;
	left: 0;
}

h3.tb {
	margin-left: 0;
	margin-right: 5px;
}

#publish {
	float: left;
}

.postbox .handlediv {
	float: left;
}

.actions {
	float: left;
}

.actions li {
	float: right;
	margin-right: 0;
	margin-left: 10px;
}

#extra-fields .actions {
    margin: -23px 0 0 -7px;
}

/* Photo Styles */
#img_container a {
	float: right;
}

#category-add input,
#category-add select {
	font-family: Tahoma, Arial;
}

.inline-editor ul.cat-checklist ul,
.categorydiv ul.categorychecklist ul,
#linkcategorydiv ul.categorychecklist ul {
	margin-left: 0;
	margin-right: 18px;
}

/* Categories */
.category-tabs li {
	padding-left: 0;
	padding-right: 8px;
}

/* Tags */
#tagsdiv #newtag {
	margin-right: 0;
	margin-left: 5px;
}

#tagadd {
	margin-left: 0;
	margin-right: 3px;
}

#tagchecklist span {
	margin-left: .5em;
	margin-right: 10px;
	float: right;
}
#tagchecklist span a {
	margin: 6px -9px 0 0;
	float: right;
}

#content {
	margin-left: 0;
	margin-right: 1%;
}

.submit input,
.button,
.button-primary,
.button-secondary,
.button-highlighted,
#postcustomstuff .submit input {
	font-family: Tahoma, Arial, sans-serif;
}

.ac_results li {
	text-align: right;
}

#TB_ajaxContent #options {
	right: auto;
	left: 25px;
}

#post_status {
	margin-left: 0;
	margin-right: 10px;
}

/* Footer */
#footer {
	padding: 10px 60px 0 0;
}









/* theme-editor */
#templateside {
	float: left;
}







/* theme-install */
div.star {
	left:auto;
	right: 0;
}

.star img, div.star a, div.star a:hover, div.star a:visited {
	right: auto;
	left: 0;
}

.theme-listing .theme-item h3 {
	font-style: normal;
}

#theme-information .theme-preview-img {
	float: right;
	margin: 5px 15px 10px 25px;
}

#theme-information .action-button #cancel {
	float: right;
}

#theme-information .action-button #install {
	float: left;
}

.feature-filter .feature-group {
	float: right;
}

.feature-filter .feature-name {
	float: right;
	text-align: left;
}

.feature-filter .feature-group li {
	float: right;
	padding-right: 0;
	padding-left: 25px;
}






/* widgets */
/* 2 column liquid layout */
div.widget-liquid-left {
	float: right;
	clear: right;
	margin-right: 0;
	margin-left: -325px;
}

div#widgets-left {
	margin-right: 5px;
	margin-left: 325px;
}

div.widget-liquid-right {
	float: left;
	clear: left;
}

.inactive-sidebar .widget {
	float: right;
}

div.sidebar-name h3 {
	font-family: Tahoma, Arial, sans-serif;
}

#widget-list .widget {
	float: right;
}

.inactive-sidebar .widget-placeholder {
	float: right;
}

.widget-top .widget-title-action {
	float: left;
}

.widget-control-edit {
	padding: 0 0 0 8px;
}


.sidebar-name-arrow {
	float: left;
}

