/* Fixes for IE bugs */

#wp-fullscreen-title {
	width: 97%;
}

#wp_mce_fullscreen_ifr {
	background-color: #f9f9f9;
}

#wp-fullscreen-tagline {
	color: #888;
	font-size: 14px;
}

#adminmenuback {
	left: 0;
}

#adminmenu li.wp-menu-separator,
#adminmenu li.wp-menu-separator-last {
	font-size: 1px;
	line-height: 1;
}

#adminmenu a.menu-top {
	border-bottom: 0 none;
	border-top: 1px solid #ddd;
}

#adminmenu .separator {
	font-size: 1px;
	line-height: 1px;
}

#wpbody-content input.button,
#wpbody-content input.button-primary,
#wpbody-content input.button-secondary,
#wpbody-content input.button-highlighted {
	overflow: visible;
}

#dashboard-widgets #dashboard_quick_press form p.submit #publish {
	float: none;
}

#dashboard-widgets h3 a {
	height: 14px;
	line-height: 14px;
}

#dashboard_browser_nag {
	color: #fff;
}

#dashboard_browser_nag .browser-icon {
	position: relative;
}

.tablenav-pages .current-page {
	vertical-align: middle;
}

#wpbody-content .postbox {
	border: 1px solid #dfdfdf;
}

#wpbody-content .postbox h3 {
	margin-bottom: -1px;
}

* html .meta-box-sortables .postbox .handlediv {
	background: transparent url(../images/menu-bits-vs.gif) no-repeat scroll left -111px;
}

* html .edit-box {
	display: inline;
}

* html .inner-sidebar #side-sortables,
* html .postbox-container .meta-box-sortables {
	height: 300px;
}

* html #wpbody-content #screen-options-link-wrap {
	display: inline-block;
	width: 150px;
	text-align: center;
}

* html #wpbody-content #contextual-help-link-wrap {
	display: inline-block;
	width: 100px;
	text-align: center;
}

* html #adminmenu {
	margin-left: -80px;
}

* html .folded #adminmenu {
	margin-left: -22px;
}

* html #wpcontent #adminmenu li.menu-top {
	display: inline;
	padding: 0;
	margin: 0;
}

* html #footer {
	margin: 0;
}

.js.folded #adminmenu li.menu-top {
	display: block;
	zoom: 100%;
}

ul#adminmenu {
	z-index: 99;
}

#adminmenu li.menu-top a.menu-top {
	min-width: auto;
	width: auto;
}

#wpcontent #adminmenu li.wp-has-current-submenu a.wp-has-submenu {
	font-style: normal;
}

* html #wpcontent #adminmenu .wp-menu-open .wp-menu-toggle {
	background: none;
}

* html #wpcontent #adminmenu .wp-has-submenu .wp-menu-toggle {
	background: url(../images/menu-bits.gif?ver=20100610) no-repeat scroll left -109px;
}

* html #wpcontent #adminmenu li.wp-has-current-submenu .wp-menu-toggle {
	background: url(../images/menu-bits.gif?ver=20100610) no-repeat scroll left -206px;
}

* html #adminmenu div.wp-menu-image {
	height: 29px;
}

#wpcontent #adminmenu .wp-submenu li {
	padding: 0;
}

#adminmenu,
.major-publishing-actions,
.wp-submenu,
.wp-submenu li,
.wp-menu-toggle,
#template,
#template div,
#editcat,
#addcat,
* html .stuffbox h3  {
	zoom: 100%;
}

#wpcontent #adminmenu .wp-submenu li.wp-submenu-head {
	padding: 3px 4px 4px 10px;
	zoom: 100%;
}

.js.folded #adminmenu .menu-top {
	height: 30px;
}

.js.folded #adminmenu .wp-submenu {
	margin: -1px 0 0 0;
}

.wp-menu-arrow {
	height: 28px;
}

.submitbox {
	margin-top: 10px;
}

/* Inline Editor */
#wpbody-content .quick-edit-row-post .inline-edit-col-left {
	width: 39%;
}

#wpbody-content .inline-edit-row-post .inline-edit-col-center {
	width: 19%;
}

#wpbody-content .quick-edit-row-page .inline-edit-col-left {
	width: 49%;
}

#wpbody-content .bulk-edit-row .inline-edit-col-left {
	width: 29%;
}

.inline-edit-row p.submit {
	zoom: 100%;
}

.inline-edit-row fieldset label span.title {
	display: block;
	float: left;
	width: 5em;
}

.inline-edit-row fieldset label span.input-text-wrap {
	margin-left: 0;
	zoom: 100%;
}

#wpbody-content .inline-edit-row fieldset label span.input-text-wrap input {
	line-height: 130%;
}

#wpbody-content .inline-edit-row .input-text-wrap input {
	width: 95%;
}

#wpbody-content .inline-edit-row .input-text-wrap input.inline-edit-password-input {
	width: 8em;
}
/* end Inline Editor */

* html .row-actions {
	visibility: visible;
}

#titlediv #title {
	width: 98%;
}

a.button {
	line-height: 1.4em;
	margin: 1px;
	padding: 2px 6px;
}

* html div.widget-liquid-left,
* html div.widget-liquid-right {
	display: block;
	position: relative;
}

#screen-options-wrap {
	overflow: hidden;
}

#favorite-actions {
	z-index: 12;
}

#favorite-inside,
#favorite-inside a,
.favorite-action {
	zoom: 100%;
}

#the-comment-list .comment-item,
#post-status-info,
#wpwrap,
#wpcontent,
#wrap,
#postdivrich,
#postdiv,
#poststuff,
.metabox-holder,
#titlediv,
#post-body,
#editorcontainer,
.tablenav,
.widget-liquid-left,
.widget-liquid-right,
#widgets-left,
.widgets-sortables,
#dragHelper,
.widget .widget-top,
.widget,
.widget-control-actions,
.tagchecklist,
#col-container,
#col-left,
#col-right,
.fileedit-sub {
	display: block;
	zoom: 100%;
}

p.search-box {
	position: static;
	float: right;
	margin: -3px 0 4px;
}

* html #editorcontainer {
	padding: 0;
}

#editorcontainer #content {
	overflow: auto;
	margin: auto;
	width: 98%;
}

form#template div {
	width: 100%;
}

#ed_toolbar input,
#ed_reply_toolbar input {
	overflow: visible;
	padding: 0 4px;
}

#poststuff h2 {
	font-size: 1.6em;
}

* html #poststuff h2 {
	margin-left: 0;
}

#bh {
	margin: 7px 10px 0 0;
	float: right;
}

/* without this dashboard widgets appear in one column for some screen widths */
div#dashboard-widgets {
	padding-right: 1px;
}

.tagchecklist span, .tagchecklist span a {
	display: inline-block;
	display: block;
}

.tagchecklist span a {
	margin: 4px 0 0 -9px;
}

.tablenav .button-secondary,
.nav .button-secondary {
	padding-top: 2px;
	padding-bottom: 2px;
}

.tablenav select {
	font-size: 13px;
	display: inline-block;
	vertical-align: top;
	margin-top: 2px;
}

.tablenav .actions select {
	width: 155px;
}

table.ie-fixed {
	table-layout: fixed;
}

.widefat tr, .widefat th {
	margin-bottom: 0;
	border-spacing: 0;
}

.widefat th input {
	margin: 0 0 0 5px;
}

.widefat .check-column {
	padding: 6px 0 2px;
}

.widefat tbody th.check-column {
	padding: 4px 0 22px;
}

.widefat {
	empty-cells: show;
	border-collapse: collapse;
}

.tablenav a.button-secondary {
	display: inline-block;
	padding: 2px 5px;
}

* html .stuffbox,
* html .stuffbox input,
* html .stuffbox textarea {
	border: 1px solid #DFDFDF;
}

* html .feature-filter .feature-group li {
	width: 145px;
}

* html .widget-top .widget-title-action a {
	background: url("../images/menu-bits.gif?ver=20100610") no-repeat scroll 0 -110px;
}

* html div.widget-liquid-left {
	width: 99%;
}

.inactive-sidebar .widgets-sortables {
	padding-bottom: 8px;
}

* html .widgets-sortables {
	height: 50px;
}

* html a#content_resize {
	right: -2px;
}

* html .widget-title h4 {
	width: 205px;
}

* html #removing-widget .in-widget-title {
	display: none;
}

#available-widgets .widget-holder {
	padding-bottom: 65px;
}

#widgets-left .inactive {
	padding-bottom: 10px;
}

.widget-liquid-right .widget,
.inactive-sidebar .widget {
	position: relative;
}

* html .media-item .pinkynail {
	height: 32px;
	width: 40px;
}

#wpcontent .button-primary-disabled {
	color: #9FD0D5;
	background: #298CBA;
}

#wpcontent #ajax-loading,
#wpcontent .ajax-loading {
	vertical-align: baseline;
}

* html .describe .field input.text,
* html .describe .field textarea {
	width: 440px;
}

#the-comment-list .unapproved tr,
#the-comment-list .unapproved td {
	background-color: #ffffe0;
}

.imgedit-submit {
	width: 300px;
}

* html input {
	border: 1px solid #dfdfdf;
}

#nav-menu-header,
#nav-menus-frame,
#wpbody,
.menu li {
	zoom:100%;
}

#update-nav-menu #post-body {
	overflow:hidden;
}

.menu li {
	min-width:100%;
}

.menu li.sortable-placeholder {
	min-width:400px;
}
