#wpadminbar * {
	height: auto;
	width: auto;
	margin: 0;
	padding: 0;
	position: static;
	text-transform: none;
	letter-spacing: normal;
	line-height: 1;
	font: normal 13px/28px "Helvetica Neue", sans-serif;
	color: #ccc;
	text-shadow: #444 0px -1px 0px;
}

#wpadminbar :before,
#wpadminbar :after {
	content: normal;
}

#wpadminbar a,
#wpadminbar a:hover,
#wpadminbar a img,
#wpadminbar a img:hover {
	outline: none;
	border: none;
	text-decoration: none;
	background: none;
}

#wpadminbar {
	direction: ltr;
	color: #ccc;
	font: normal 13px/28px "Helvetica Neue", sans-serif;
	height: 28px;
	position: fixed;
	top: 0;
	left: 0;
	width: 100%;
	z-index: 99999;
	min-width: 960px;

	background-color: #464646; /* Fallback */
	background-image: -ms-linear-gradient(bottom, #464646, #373737 5px); /* IE10 */
	background-image: -moz-linear-gradient(bottom, #464646, #373737 5px); /* Firefox */
	background-image: -o-linear-gradient(bottom, #464646, #373737); /* Opera */
	background-image: -webkit-gradient(linear, left bottom, left top, from(#464646), to(#373737)); /* old Webkit */
	background-image: -webkit-linear-gradient(bottom, #373737, #464646 5px); /* new Webkit */
	background-image: linear-gradient(bottom, #464646, #373737); /* proposed W3C Markup */
}

#wpadminbar ul,
#wpadminbar ul li {
	background: none;
	list-style: none;
	margin: 0;
	padding: 0;
	position: relative;
	z-index: 99999;
}

#wpadminbar .quicklinks {
	border-left: 1px solid transparent;
}

#wpadminbar .quicklinks ul {
	text-align: left;
}

#wpadminbar li {
	float: left;
}

#wpadminbar .quicklinks > ul > li {
	border-right: 1px solid #555;
}
#wpadminbar .quicklinks > ul > li > a {
	border-right: 1px solid #333;
}
#wpadminbar .quicklinks > ul > li.opposite {
	border-left: 1px solid #333;
	border-right: 0;
}
#wpadminbar .quicklinks > ul > li.opposite > a {
	border-left: 1px solid #555;
	border-right: 0;
}

/*#wpadminbar .quicklinks > ul > li:last-child > a {
	border-right: none;
}*/

#wpadminbar .quicklinks a,
#wpadminbar .shortlink-input {
	height: 28px;
	display: block;
	padding: 0 1em;
	margin: 0;
}

#wpadminbar .quicklinks a > span {
	line-height: 28px;
}

#wpadminbar .quicklinks .menupop ul,
#wpadminbar .shortlink-input {
	margin: 0 0 0 -1px;
	padding: 6px 0;
	-moz-box-shadow: 0 4px 6px rgba(0,0,0,0.2);
	-webkit-box-shadow: 0 4px 6px rgba(0,0,0,0.2);
	box-shadow: 0 4px 6px rgba(0,0,0,0.2);
	background: #fff;
	display: none;
	position: absolute;
	float: none;
	border-width: 0 1px 1px 1px;
	border-style: solid;
	border-color: #dfdfdf;
}
#wpadminbar .quicklinks .opposite.menupop ul {
	right: 0;
	margin: 0 -1px 0 0;
}

#wpadminbar .selected .shortlink-input {
	display: block;
}

#wpadminbar .quicklinks .menupop ul li {
	float: none;
}

#wpadminbar .quicklinks .menupop ul li a strong {
	font-weight: bold;
}

#wpadminbar .quicklinks .menupop ul li a,
#wpadminbar .quicklinks .menupop ul li a span,
#wpadminbar .quicklinks .menupop ul li a strong,
#wpadminbar .quicklinks .menupop.hover ul li a,
#wpadminbar .quicklinks .menupop.hover ul li a span,
#wpadminbar.nojs .quicklinks .menupop:hover ul li a,
#wpadminbar.nojs .quicklinks .menupop:hover ul li a span,
#wpadminbar .shortlink-input {
	line-height: 26px;
	height: 26px;
	color: #21759B;
	text-shadow: none;
	white-space: nowrap;
	min-width: 140px;
}

#wpadminbar .shortlink-input {
	width: 200px;
}

#wpadminbar.nojs .quicklinks li:hover > ul,
#wpadminbar .quicklinks li.hover > ul {
	display: block;
}

#wpadminbar .quicklinks .menupop li:hover > ul,
#wpadminbar .quicklinks .menupop li.hover > ul {
	margin-left: 100%;
	margin-top: -33px;
	border-width: 1px;
}

#wpadminbar .quicklinks .opposite.menupop li:hover > ul,
#wpadminbar .quicklinks .opposite.menupop li.hover > ul {
	margin-left: 0;
	left: inherit;
	right: 100%;
}

#wpadminbar .ab-top-menu > li:hover {
	/* @todo: add other gradients */
	background-image: -webkit-linear-gradient(bottom, #3a3a3a, #222); /* new Webkit */
}

#wpadminbar.nojs .ab-top-menu > li.menupop:hover,
#wpadminbar .ab-top-menu li.menupop.hover,
#wpadminbar .ab-top-menu .selected.screen-meta-toggle {
	background: #fff;
}

#wpadminbar.nojs .quicklinks .menupop:hover a,
#wpadminbar.nojs .quicklinks .menupop:hover span,
#wpadminbar .quicklinks .menupop.hover a,
#wpadminbar .quicklinks .menupop.hover span,
#wpadminbar .ab-top-menu .selected.screen-meta-toggle a,
#wpadminbar .ab-top-menu .selected.screen-meta-toggle span {
	color: #333;
	text-shadow: none;
}


#wpadminbar .quicklinks .menupop li:hover,
#wpadminbar .quicklinks .menupop li.hover {
	background-color: #eaf2fa;
}

#wpadminbar .ab-top-menu > .menupop > a span {
	padding-right: 10px;
	margin-right: -10px;
	white-space: nowrap;
}
#wpadminbar .ab-top-menu > li > a:hover,
#wpadminbar .ab-top-menu > li > a:hover span {
	color: #fafafa;
}
#wpadminbar .ab-top-menu > li > a:hover span {
	background: url(../images/admin-bar-sprite.png?d=11122010) right -57px no-repeat;
}
#wpadminbar.nojs .ab-top-menu > li > a:hover span,
#wpadminbar .ab-top-menu > li.hover > a:hover span {
	background: none;
}

#wpadminbar .menupop li a > span {
	display: block;
	background: url(../images/admin-bar-sprite.png?d=11122010) right -31px no-repeat;
	padding: 0 1.5em 0 0;
}
#wpadminbar .opposite.menupop li a > span {
	background-position: -28px -31px;
	padding: 0 0 0 1.5em;
}

#wpadminbar .quicklinks .menupop .secondary {
	background: #eee;
	margin: 6px 0 -6px;
	border-top: 1px solid #dfdfdf;
}

#wpadminbar .quicklinks .menupop .secondary > a {
	display: none;
}
#wpadminbar .quicklinks .menupop li.secondary > ul,
#wpadminbar .quicklinks .opposite.menupop li.secondary > ul {
	display: block;
	position: relative;
	right: auto;
	margin: 0;
	border: 0;

	-moz-box-shadow: none;
	-webkit-box-shadow: none;
	box-shadow: none;

	background: #eee;
}

#wpadminbar .quicklinks .menupop li.secondary > ul > li:hover,
#wpadminbar .quicklinks .menupop li.secondary > ul > li.hover {
	background: #dfdfdf;
}

#wpadminbar .quicklinks a span#ab-updates {
	background: #eee;
	color: #333;
	text-shadow: none;
	display: inline;
	padding: 2px 5px;
	font-size: 10px;
	font-weight: bold;
	-moz-border-radius: 10px;
	-khtml-border-radius: 10px;
	-webkit-border-radius: 10px;
	border-radius: 10px;
}

#wpadminbar .quicklinks a:hover span#ab-updates  {
	background: #fff;
	color: #000;
}

#wpadminbar li.opposite {
	float: right;
}

#wp-admin-bar-my-account > ul {
	min-width: 270px;
}
#wpadminbar #wp-admin-bar-my-account .user-info-item {
	margin-left: 88px;
	margin-right: 16px;
}
#wpadminbar #wp-admin-bar-my-account .user-info-item > a {
	padding-left: 8px;
}

#wpadminbar #wp-admin-bar-my-account .user-info {
	margin-top: 6px;
	margin-bottom: 15px;
	height: auto;
	background: none;
}
#wp-admin-bar-my-account .user-info .avatar {
	position: absolute;
	left: -72px;
	top: 4px;
}
#wpadminbar #wp-admin-bar-my-account .user-info a {
	height: auto;
}
#wpadminbar #wp-admin-bar-my-account .user-info span {
	background: none;
	padding: 0;
	height: 18px;
}
#wpadminbar #wp-admin-bar-my-account .user-info .display-name {
	color: #333;
}
#wpadminbar #wp-admin-bar-my-account .user-info .username {
	color: #999;
	font-size: 11px;
}

#wpadminbar .quicklinks li#wp-admin-bar-my-account.with-avatar > a img {
	width: 16px;
	height: 16px;
	border: 1px solid #999;
	padding: 0;
	background: #eee;
	line-height: 24px;
	vertical-align: middle;
	margin: -2px 0 0 6px;
}

#wpadminbar .quicklinks li img.blavatar {
	vertical-align: middle;
	margin: -3px 4px 0 0;
	padding: 0;
}

#wpadminbar #wp-admin-bar-search {
	border-right: 0;
}

#wpadminbar #wp-admin-bar-search a {
	padding: 0;
	border-right: 0;
}

#wpadminbar .quicklinks .admin-bar-search:hover {
	/* default background */
	background: transparent;
}

#wpadminbar #adminbarsearch {
	float: right;
	height: 24px;
	padding: 2px 4px;
	margin: 0;
}


#wpadminbar #adminbarsearch .adminbar-input {
	height: 23px;
	width: 140px;
	float: left;
	font: 13px "Helvetica Neue", sans-serif;
	border: none;
	padding: 0 3px 0 24px;
	margin: 0 3px 0 0;

	color: #ccc;
	text-shadow: #444 0px -1px 0px;
	background-color: rgba( 255, 255, 255, 0 );

	/* @todo: replace/move twenty eleven image to a core search icon. */
	background-image: url('../../wp-content/themes/twentyeleven/images/search.png');
	background-repeat: no-repeat;
	background-position: 4px 2px;

	-webkit-border-radius: 3px;
	-khtml-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;

	-moz-box-shadow: none;
	-webkit-box-shadow: none;
	box-shadow: none;

	-moz-box-sizing: border-box;
	-webkit-box-sizing: border-box;
	-ms-box-sizing: border-box;
	box-sizing: border-box;
	outline: none;

	-webkit-transition-duration: 400ms;
	-webkit-transition-property: width, background;
	-webkit-transition-timing-function: ease;
	-moz-transition-duration: 400ms;
	-moz-transition-property: width, background;
	-moz-transition-timing-function: ease;
	-o-transition-duration: 400ms;
	-o-transition-property: width, background;
	-o-transition-timing-function: ease;
}

#wpadminbar #adminbarsearch .adminbar-input:focus {
	color: #555;
	text-shadow: 0 1px 0 #fff;
	width: 200px;
	background-color: rgba( 255, 255, 255, 0.9 );
}

/* Two rules to ensure browser recognition */
#wpadminbar #adminbarsearch .adminbar-input::-webkit-input-placeholder {
	color: #ddd;
}
#wpadminbar #adminbarsearch .adminbar-input:-moz-placeholder {
	color: #ddd;
}


#wpadminbar #adminbarsearch .adminbar-button {
	display: none;
}

#wpadminbar #adminbarsearch .adminbar-button:active {
	background: #a0a0a0;
	background:-moz-linear-gradient(bottom,  #a0a0a0,  #c1c1c1);
	background:-webkit-gradient(linear, left bottom, left top, from(#a0a0a0), to(#c1c1c1));
	-moz-box-shadow: inset 1px 1px 1px #9b9b9b;
	-webkit-box-shadow: inset 1px 1px 1px #9b9b9b;
	box-shadow: inset 1px 1px 1px #9b9b9b;
}

#wpadminbar #adminbarsearch .adminbar-button:hover {
	color: #000;
}

#wpadminbar #adminbarsearch .adminbar-button::-moz-focus-inner {
	border: none;
}

/**
 * WP Logo item
 */

#wpadminbar .wp-admin-bar-logo > a {
	padding-left: 24px;
	background: url(../images/wp-logo-white.png) no-repeat 13px 6px;
}
#wpadminbar .wp-admin-bar-logo > a span {
	height: 28px;
}

#wpadminbar.nojs .wp-admin-bar-logo:hover > a,
#wpadminbar .wp-admin-bar-logo.hover > a {
	background: url(../images/wp-logo-dark.png) no-repeat 12px 6px;
}

/**
 * Comments icon
 */
#wpadminbar .ab-comments-icon {
	position: relative;
	padding-top: 5px;
	float: left;
}
#wpadminbar .ab-comments-icon-body {
	margin: 3px 4px 0 -2px;
	background: #999;
	height: 10px;
	width: 14px;

	-moz-border-radius: 10px;
	-khtml-border-radius: 10px;
	-webkit-border-radius: 10px;
	border-radius: 10px;
}

#wpadminbar a:hover .ab-comments-icon-body {
	background: #bbb;
	color: #555;
}

#wpadminbar a .ab-comments-icon-arrow {
	height: 0;
	position: absolute;
	bottom: -3px;
	left: 1px;
	/* Use transparent borders to form a triangle */
	border-left: 4px solid #999;
	border-bottom: 4px solid transparent;
}
#wpadminbar a:hover .ab-comments-icon-arrow {
	border-left-color: #bbb;
}


/**
 * IE 6-targeted rules
 */
* html #wpadminbar {
	overflow: hidden;
	position: absolute;
}

* html #wpadminbar .quicklinks ul li a {
	float: left;
}

* html #wpadminbar .menupop a span {
	background-image: none;
}
